@@ -35,10 +35,10 @@
 #include <math.h>
 #include "eel-canvas-rect-ellipse.h"
 #include "eel-canvas-util.h"
-#include <gdk/gdkx.h>
 #include <string.h>
 
 #ifdef HAVE_RENDER
+#include <gdk/gdkx.h>
 #include <X11/extensions/Xrender.h>
 #endif
 
@@ -885,7 +885,11 @@ render_rect_alpha (EelCanvasRect *rect,
 	a = (rgba >> 0) & 0xff;
 
 #ifdef HAVE_RENDER
-	if (priv->use_render) {
+	/* Every visual is not guaranteed to have a matching
+	 * XRenderPictFormat. So make sure that format is not null before
+	 * trying to render using Xrender calls.
+	 */
+	if (priv->use_render && (priv->format != NULL)) {
 		GdkDrawable *real_drawable;
 		int x_offset, y_offset;
 
